| Title: | Houston, We Have a Problem |
|---|---|
| Description: | Import a number of helper functions without exposing any evil underscores. |
| Authors: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-05-26 06:20:20 UTC |
| Source: | https://github.com/eddelbuettel/apollo13 |
Some people write packages with too many underscores, and too many imports shadowing other packages. This package addresses both problems by selectively importing just a few key funtions and carefully renaming them. To camelCase, naturally.
This mostly uses facilities now available via the NAMESPACE mechanism.
Dirk Eddelbuettel
Maintainer: Dirk Eddelbuettel <[email protected]>
buildPackage
buildPackage(...)buildPackage(...)
... |
passed on to |
installGithub
installGithub(...)installGithub(...)
... |
passed on to |